"""
A module for every constant of asymmetric.
"""

# Logs
LOG_FILE_NAME = "asymmetric.log"

# HTTP related
HTTP_METHODS = [
    "get",
    "put",
    "post",
    "delete",
    "options",
    "head",
    "patch",
    "trace",
]
